@@ -1,10 +1,11 @@
 #' Setup and initialize some scripts.
 #'
 #' @param bin path to bin folder
+#' @param flow_base_path the root folder for all flowr operations
 #'
 #' @details Will add more to this to identify cluster and aid in other things
 #' @export
-setup <- function(bin = "~/bin"){
+setup <- function(bin = "~/bin", flow_base_path = get_opts("flow_base_path")){
 	pkg = "flowr"
 	if(!file.exists(bin)) dir.create(bin) ## create bin, if it does not exist
 	script = file.path(bin, pkg)
@@ -16,10 +17,9 @@ setup <- function(bin = "~/bin"){
 		"\nexport PATH=$PATH:$HOME/bin",
 		"\nYou may now use all R functions using 'flowr' from shell.")
 
-	message("Creating a directory structure under ",
-		get_opts("flow_base_path"))
-	dir.create(get_opts("flow_base_path"), showWarnings = FALSE)
-	dir.create(get_opts("flow_conf_path"), showWarnings = FALSE)
-	dir.create(get_opts("flow_run_path"), showWarnings = FALSE)
+	message("Creating a directory structure under ", flow_base_path)
+	dir.create(flow_base_path, showWarnings = FALSE)
+	dir.create(flow_base_path, showWarnings = FALSE)
+	dir.create(flow_base_path, showWarnings = FALSE)
 	message(tmp)
 }
